//
// Created by welsch on 25.06.18.
//

#include "DataManager.h"
#include <iostream>


DataManager::DataManager(std::string filedir,
                         std::vector<std::string> file_names) :
                            m_filedir{filedir},
                            m_file_names{file_names} {
    m_tfile = std::make_shared<TFile>((m_filedir + "/temp_tfile.root").c_str(),
            "recreate");
}

void DataManager::load_trees_from_file(const std::string &tree_name) {
    for(const auto& file_name : m_file_names) {
        auto tfile = std::make_shared<TFile>((m_filedir + "/" + file_name +
                ".root").c_str());

        if(tfile->IsZombie()) {
            std::cerr << "File " << file_name + ".root" <<
                      " does not exist." << std::endl;
            throw std::runtime_error("File does not exist");
        }

        std::shared_ptr<TTree> ttree(dynamic_cast<TTree *>(tfile->Get(
                tree_name.c_str())));

        m_tfile->cd();
        std::shared_ptr<TTree> copy_tree(ttree->CloneTree());
        copy_tree->SetName(file_name.c_str());
        copy_tree->Write();

        m_mtrees.emplace(file_name, copy_tree);
    }
}


std::map<std::string, std::shared_ptr<RooDataSet>> DataManager::load_datasets_from_file(
        std::string var_set_name,
        RooArgSet var_set,
        RooRealVar weight,
        const std::string &tree_name) {
    std::cout << "Load template data:" << std::endl;

    std::map<std::string, std::shared_ptr<RooDataSet>> mdataset;
    load_trees_from_file(tree_name);

    if(m_tfile->IsZombie()) {
        std::cerr << "File " << "temp_tfile.root" <<
                  " does not exist." << std::endl;
        throw std::runtime_error("File does not exist");
    }

    for(const auto &entry : m_mtrees) {
        auto dset_name = entry.first + "_" + var_set_name;
        auto rds = std::make_shared<RooDataSet>(dset_name.c_str(),
                dset_name.c_str(), var_set,
                RooFit::WeightVar(weight), RooFit::Import(*(entry.second)));
        std::cout << "\t" << rds->sumEntries() <<
                  " " + entry.first +  " events loaded." << std::endl;
        mdataset.emplace(entry.first, rds);
    }

    return mdataset;
}

