//
// Created by welsch on 15.06.18.
//

#include <iostream>
#include <vector>
#include <string>
#include <map>
#include <memory>
#include <RooMinuit.h>


#include "TH1F.h"
#include "TCanvas.h"
#include "TFile.h"
#include "TTree.h"
#include "TString.h"
#include "TH2.h"

#include "RooRealVar.h"
#include "RooGaussian.h"
#include "RooDataSet.h"
#include "RooPlot.h"
#include "RooHist.h"
#include "RooBreitWigner.h"
#include "RooArgusBG.h"
#include "RooAddPdf.h"
#include "RooArgList.h"
#include "RooHistPdf.h"
#include "RooAbsPdf.h"
#include "RooAbsReal.h"
#include "RooDataHist.h"
#include "RooNLLVar.h"
#include "RooMCStudy.h"
#include "RooFitResult.h"

#include "TFileManager.h"
#include "FitUtils.h"

using namespace RooFit;
using namespace ROOT;
using namespace std;


int main() {
    // load root files into map
    vector<TString> vfile_names{"Data", "PI0Signal", "PI0xulnu", "PI0remaining"};
    TFileManager fileManager(vfile_names);
    map<TString, shared_ptr<TTree>> mtrees = load_ttrees(fileManager,
                                                         vfile_names,
                                                         "mytree");

    RooRealVar missing_mass("missingMass", "Missing Mass", -1, 3);
    missing_mass.setBins(30);
    RooDataSet data("data", "missing Mass data", mtrees["Data"].get(), missing_mass);


    RooRealVar weight("weight", "Event Weight", -5, 5);
    RooRealVar weight2("weight", "bkg weight",  -5, 5);
    (*mtrees["PI0xulnu"]).Print();

    RooDataSet dsig("sig", "Signal Data", RooArgSet(missing_mass, weight),
                    WeightVar(weight), Import(*mtrees["PI0Signal"]));

    RooDataSet dbkg("bkg", "Background Data", RooArgSet(missing_mass, weight2),
                    WeightVar(weight2), Import(*mtrees["PI0xulnu"]));


    RooDataSet dcont("cont", "Continuum Data", RooArgSet(missing_mass, weight),
                     WeightVar(weight), Import(*mtrees["PI0remaining"]));

    RooHistPdf sigpdf("sigpdf", "Signal PDF", missing_mass, *(dsig.binnedClone()));



    RooHistPdf bkgpdf("bkgpdf", "Background PDF", missing_mass, *(dbkg.binnedClone()));
    RooHistPdf contpdf("contpdf", "Continuum PDF", missing_mass, *(dcont.binnedClone()));
    RooRealVar nsig("nsig", "Signal Yield", 0, 1000);
    RooRealVar nbkg("nbkg", "Background Yield", 0, 6000);
    RooRealVar ncont("ncont", "Continuum Yield", 0, 1000);

    RooAddPdf bkg_model("bkg", "bkg", RooArgList(bkgpdf, contpdf), RooArgList(nbkg, ncont));
    RooAddPdf model("model", "model", RooArgList(sigpdf, bkgpdf, contpdf), RooArgList(nsig, nbkg, ncont));

    RooFitResult  *result = model.fitTo(data, Extended(kTRUE), NumCPU(4));
    result->Print("v");
    RooNLLVar nll("nll", "nll", model, data);

    RooPlot *mmframe = missing_mass.frame();
    data.plotOn(mmframe);
    model.plotOn(mmframe,Components(RooArgSet(contpdf, sigpdf, bkgpdf)), DrawOption("F"), FillColor(kBlue));
    model.plotOn(mmframe,Components(RooArgSet(contpdf, bkgpdf)), DrawOption("F"), FillColor(kRed));
    model.plotOn(mmframe,Components(RooArgSet(contpdf)), DrawOption("F"), FillColor(kYellow));
    data.plotOn(mmframe);
    TCanvas c;
    mmframe->Draw();
    c.SaveAs("fittodata2.pdf", "pdf");
    c.Clear();



    RooMCStudy *mgr = new RooMCStudy(model, missing_mass, Extended(kTRUE),
            Silence(kTRUE), NumCPU(4), FitOptions(Save(kTRUE)));
    mgr->generateAndFit(1000);

    auto eframe = mgr->plotPull(nbkg, FitGauss(kTRUE));
    auto mframe = mgr->plotPull(ncont, FitGauss(kTRUE));
    auto pframe = mgr->plotPull(nsig, FitGauss(kTRUE));

    TCanvas cc;
    cc.Divide(2,2);
    cc.cd(1);
    mframe->Draw();
    cc.cd(2);
    eframe->Draw();
    cc.cd(3);
    pframe->Draw();
    cc.SaveAs("asdf.pdf", "pdf");
//
//
//

    return 0;

}


